Module game_assistant_api

Module game_assistant_api 

Structs

AskGameAssistantParams
struct for passing parameters to the method ask_game_assistant

Enums

AskGameAssistantError
struct for typed errors of method ask_game_assistant

Functions

ask_game_assistant
Ask the game assistant a question about game mechanics or public API usage. An active membership is required. Members receive a limited number of free questions per day. When no free question is available, the request can spend 1 gem with pay_with_gems=true.