pub enum AskGameAssistantError {
Status451(ErrorResponseSchema),
Status570(ErrorResponseSchema),
Status563(ErrorResponseSchema),
Status422(ErrorResponseSchema),
}Expand description
struct for typed errors of method ask_game_assistant
Variants
Status451(ErrorResponseSchema)
Access denied, you must be a member to do that.
Status570(ErrorResponseSchema)
You have reached the daily limit for assistant questions. Try again tomorrow.
Status563(ErrorResponseSchema)
Insufficient gems.
Status422(ErrorResponseSchema)
Request could not be processed due to an invalid payload.