pub enum BuySubscriptionError {
Status563(ErrorResponseSchema),
Status573(ErrorResponseSchema),
Status422(ErrorResponseSchema),
}Expand description
struct for typed errors of method buy_subscription
Variants
Status563(ErrorResponseSchema)
Insufficient gems.
Status573(ErrorResponseSchema)
An active Stripe subscription cannot be extended with gems or member tokens.
Status422(ErrorResponseSchema)
Request could not be processed due to an invalid payload.