pub async fn get_map_by_position(
configuration: &Configuration,
params: GetMapByPositionParams,
) -> Result<MapResponseSchema, Error<GetMapByPositionError>>Expand description
Retrieve the details of a map by layer and coordinates.
pub async fn get_map_by_position(
configuration: &Configuration,
params: GetMapByPositionParams,
) -> Result<MapResponseSchema, Error<GetMapByPositionError>>Retrieve the details of a map by layer and coordinates.