pub struct GetLayerMapsParams {
pub layer: MapLayer,
pub content_type: Option<MapContentType>,
pub content_code: Option<String>,
pub hide_blocked_maps: Option<bool>,
pub hide_event: Option<bool>,
pub transition: Option<bool>,
pub page: Option<u32>,
pub size: Option<u32>,
}Expand description
struct for passing parameters to the method get_layer_maps
Fields
layer: MapLayerThe layer of the map (interior, overworld, underground).
content_type: Option<MapContentType>Type of maps.
content_code: Option<String>Content code on the map.
hide_blocked_maps: Option<bool>When true, excludes maps with access_type ‘blocked’ from the results.
hide_event: Option<bool>When true, does not overlay active events on maps.
transition: Option<bool>Filter maps by transition. True returns only maps with transitions, False returns only maps without.
page: Option<u32>Page number
size: Option<u32>Page size
Implementations