pub enum ClaimPendingItemError {
Status404(ErrorResponseSchema),
Status498(ErrorResponseSchema),
Status497(ErrorResponseSchema),
Status499(ErrorResponseSchema),
Status486(ErrorResponseSchema),
Status422(ErrorResponseSchema),
}Expand description
struct for typed errors of method claim_pending_item
Variants
Status404(ErrorResponseSchema)
Pending item not found.
Status498(ErrorResponseSchema)
Character not found.
Status497(ErrorResponseSchema)
The character's inventory is full.
Status499(ErrorResponseSchema)
The character is in cooldown.
Status486(ErrorResponseSchema)
An action is already in progress for this character.
Status422(ErrorResponseSchema)
Request could not be processed due to an invalid payload.