pub enum GeCreateBuyOrderError {
Status498(ErrorResponseSchema),
Status499(ErrorResponseSchema),
Status486(ErrorResponseSchema),
Status404(ErrorResponseSchema),
Status492(ErrorResponseSchema),
Status433(ErrorResponseSchema),
Status437(ErrorResponseSchema),
Status598(ErrorResponseSchema),
Status422(ErrorResponseSchema),
}Expand description
struct for typed errors of method ge_create_buy_order
Variants
Status498(ErrorResponseSchema)
Character not found.
Status499(ErrorResponseSchema)
The character is in cooldown.
Status486(ErrorResponseSchema)
An action is already in progress for this character.
Status404(ErrorResponseSchema)
Item not found.
Status492(ErrorResponseSchema)
The character does not have enough gold.
Status433(ErrorResponseSchema)
You cannot create more than 100 orders at the same time.
Status437(ErrorResponseSchema)
This item cannot be sold.
Status598(ErrorResponseSchema)
Grand Exchange not found on this map.
Status422(ErrorResponseSchema)
Request could not be processed due to an invalid payload.