pub enum GeFillOrderError {
Status598(ErrorResponseSchema),
Status498(ErrorResponseSchema),
Status499(ErrorResponseSchema),
Status436(ErrorResponseSchema),
Status486(ErrorResponseSchema),
Status478(ErrorResponseSchema),
Status434(ErrorResponseSchema),
Status435(ErrorResponseSchema),
Status404(ErrorResponseSchema),
Status422(ErrorResponseSchema),
}Expand description
struct for typed errors of method ge_fill_order
Variants
Status598(ErrorResponseSchema)
Grand Exchange not found on this map.
Status498(ErrorResponseSchema)
Character not found.
Status499(ErrorResponseSchema)
The character is in cooldown.
Status436(ErrorResponseSchema)
A transaction is already in progress for this order by another character.
Status486(ErrorResponseSchema)
An action is already in progress for this character.
Status478(ErrorResponseSchema)
Missing required item(s).
Status434(ErrorResponseSchema)
This offer does not contain that many items.
Status435(ErrorResponseSchema)
You cannot trade with yourself.
Status404(ErrorResponseSchema)
Buy order not found.
Status422(ErrorResponseSchema)
Request could not be processed due to an invalid payload.