pub struct RaidInstanceSchema {
pub starts_at: String,
pub ends_at: String,
pub status: RaidStatus,
pub total_hp: u32,
pub remaining_hp: u32,
pub participant_count: Option<u32>,
pub ended_at: Option<String>,
pub result: Option<RaidInstanceResult>,
pub rewards_distributed_at: Option<String>,
}Fields
starts_at: StringWeekly raid opening datetime in UTC.
ends_at: StringWeekly raid planned closing datetime in UTC.
status: RaidStatusCurrent status of this weekly raid instance.
total_hp: u32Shared HP pool when this raid instance starts.
remaining_hp: u32Remaining shared HP pool for this raid instance.
participant_count: Option<u32>Number of accounts that contributed during this raid instance.
ended_at: Option<String>Datetime when this raid instance actually ended.
result: Option<RaidInstanceResult>Final result for this raid instance.
rewards_distributed_at: Option<String>Datetime when rewards were distributed for this raid instance.
Implementations
Sourceimpl RaidInstanceSchema
impl RaidInstanceSchema
pub fn new( starts_at: String, ends_at: String, status: RaidStatus, total_hp: u32, remaining_hp: u32, ) -> RaidInstanceSchema