RaidSchema

Struct RaidSchema 

pub struct RaidSchema {
    pub code: String,
    pub name: String,
    pub description: Option<String>,
    pub monster: String,
    pub schedule: Box<RaidScheduleSchema>,
    pub rewards: Option<Box<RaidRewardsSchema>>,
    pub status: RaidStatus,
    pub next_start_at: String,
    pub participant_count: Option<u32>,
    pub active_instance: Option<Box<RaidInstanceSchema>>,
    pub latest_instance: Option<Box<RaidInstanceSchema>>,
}

Fields

code: String

Raid code.

name: String

Raid name.

description: Option<String>

Raid description.

monster: String

Monster code used for raid combat simulation.

schedule: Box<RaidScheduleSchema>

Weekly raid opening schedule.

rewards: Option<Box<RaidRewardsSchema>>

Reward rules for the raid.

status: RaidStatus

Current overall raid status.

next_start_at: String

Datetime for the next scheduled raid opening in UTC.

participant_count: Option<u32>

Number of distinct accounts that contributed to the active or latest raid instance.

active_instance: Option<Box<RaidInstanceSchema>>

Currently active weekly raid instance, if any.

latest_instance: Option<Box<RaidInstanceSchema>>

Latest weekly raid instance, active or finished.

Implementations

Source

impl RaidSchema

pub fn new( code: String, name: String, monster: String, schedule: RaidScheduleSchema, status: RaidStatus, next_start_at: String, ) -> RaidSchema