pub struct SkinSchema {
pub code: String,
pub name: String,
pub description: String,
pub default: bool,
pub price: Option<i32>,
}Fields
code: StringThe code of the skin. This is the skin’s unique identifier.
name: StringDisplay name of the skin.
description: StringDescription of the skin and how to obtain it.
default: boolWhether this skin is available to all players by default.
price: Option<i32>Price in gems to purchase this skin. Null if not purchasable.
Implementations
Sourceimpl SkinSchema
impl SkinSchema